@@ -57,7 +57,7 @@ you need to add to your program is the tie function as in:
 use vars qw(@ISA @EXPORT_OK $VERSION);
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(shutdown);
-$VERSION = '1.86_10';
+$VERSION = '1.86_11';
 
 my $Initialized;       #-- only _initialize() once
 my $Debug = 0;         #-- pretty hokey
@@ -348,6 +348,46 @@ I was able to associate attributes to globs created by this module
 
 Please see Net-SSLeay-Handle-0.50/Changes file.
 
+=head1 BUGS
+
+If you encounter a problem with this module that you believe is a bug,
+please report it in one of the following ways:
+
+=over
+
+=item *
+
+L<create a new issue|https://github.com/radiator-software/p5-net-ssleay/issues/new>
+under the Net-SSLeay GitHub project at
+L<https://github.com/radiator-software/p5-net-ssleay>;
+
+=item *
+
+L<open a ticket|https://rt.cpan.org/Ticket/Create.html?Queue=Net-SSLeay> using
+the CPAN RT bug tracker's web interface at
+L<https://rt.cpan.org/Dist/Display.html?Queue=Net-SSLeay>;
+
+=item *
+
+send an email to the CPAN RT bug tracker at
+L<bug-Net-SSLeay@rt.cpan.org|mailto:bug-Net-SSLeay@rt.cpan.org>.
+
+=back
+
+Please make sure your bug report includes the following information:
+
+=over
+
+=item * the code you are trying to run;
+
+=item * your operating system name and version;
+
+=item * the output of C<perl -V>;
+
+=item * the version of OpenSSL or LibreSSL you are using.
+
+=back
+
 =head1 AUTHOR
 
 Originally written by Jim Bowlin.
@@ -378,6 +418,11 @@ Copyright (c) 2018- Heikki Vatiainen <hvn@radiatorsoftware.com>
 
 All rights reserved.
 
+=head1 LICENSE
+
+This module is released under the terms of the Artistic License 2.0. For
+details, see the C<LICENSE> file distributed with Net-SSLeay's source code.
+
 =head1 SEE ALSO
 
 Net::SSLeay, perl(1), http://openssl.org/
